@@ -32,20 +32,7 @@ test_that("par.uncertainty throws a warning for more than 3 columns", {
 
 
 
-test_that("par.uncertainty does not throw error for valid data input", {
-  # Generate an example variogram model using vario.mod
-  vario_mod_output <- suppressWarnings(
-    vario.mod(data = birth, max.dist = 600, fit.method = 7, shinyresults = F)
-  )
-  expect_no_error(suppressWarnings(par.uncertainty(vario_mod_output, 1, B = 10)))
 
-  # type in variogram estimate manually
-  expect_no_error(
-    suppressWarnings(
-      par.uncertainty(par.est = c(1021.812, 225440.3, 0), data = birth, max.dist = 1000, nbins = 13, B = 10)
-    )
-  )
-})
 
 
 
